pub enum HttpMethod {
GET,
POST,
PUT,
DELETE,
PATCH,
CONNECT,
OPTIONS,
TRACE,
HEAD,
}Expand description
HTTP Methods supported by the client
This enum represents the standard HTTP methods that can be used
when making requests with the HttpClient.
Variants
GET
The GET method requests a representation of the specified resource. Requests using GET should only retrieve data.
POST
The POST method is used to submit an entity to the specified resource, often causing a change in state or side effects on the server.
PUT
The PUT method replaces all current representations of the target resource with the request payload.
DELETE
The DELETE method deletes the specified resource.
PATCH
The PATCH method is used to apply partial modifications to a resource.
CONNECT
The CONNECT method establishes a tunnel to the server identified by the target resource.
OPTIONS
The OPTIONS method is used to describe the communication options for the target resource.
TRACE
The TRACE method performs a message loop-back test along the path to the target resource.
HEAD
The HEAD method asks for a response identical to that of a GET request, but without the response body.
Implementations